<?php
/**
 * WP-WebsiteToolbox admin settings
 */

// Website Toolbox URL For validate login as we ll as update SSO URLS.
define('WTBSETTINGSPAGEURL', 'https://www.websitetoolbox.com/tool/members/mb/settings');

/* Purpose: this function is used to activate the plugin.
Parameter: None
Return: None */
function websitetoolbox_activate() {
    // If page is already exist (in draft) then publish same page.
    $websitetoolboxpage_id = get_option('websitetoolbox_pageid');
    if($websitetoolboxpage_id) {
        $wtbPost = get_post($websitetoolboxpage_id);
        if($wtbPost) {
            $wtbPostData = array(
                'ID'           => $websitetoolboxpage_id,
                'post_status'   => 'publish'
            );
            wp_update_post($wtbPostData);
        }
    }
    $_SESSION['wtbPluginActivated'] = 1;
}

/* Purpose: this function is used to de-activate the plugin.
Parameter: None
Return: None */
function websitetoolbox_deactivate() {
    // hide the Website Toolbox forum page if it exists
    $websitetoolboxpage_id = get_option('websitetoolbox_pageid');
    if($websitetoolboxpage_id) {
        $wtbPost = get_post($websitetoolboxpage_id);
        if($wtbPost) {
            $wtbPostData = array(
                'ID'           => $websitetoolboxpage_id,
                'post_status'   => 'draft'
            );
            wp_update_post($wtbPostData);
        }
    }
}

/* Purpose: function is used to create Website Toolbox page on the WordPress website with default title "Forum"
Parameter: None
Return: None */
function create_websitetoolbox_page() {
    $my_post = array();
    //get post data on the basis of postid.
    $forumPostId = get_option('websitetoolbox_pageid');
    $forumPostData = get_post($forumPostId);
    // Use default post titile "Forum" if not already added by the client.
    // If client alrady added embed code or custom link on his website then didn't created new post.
    if($forumPostData->post_title) {
        $my_post['post_title'] = $forumPostData->post_title;
    } else {
        $my_post['post_title'] = "Forum";
    }
    $my_post['post_content'] = "Please go to the admin section and change your Website Toolbox forum settings.";
    $my_post['post_status'] = 'publish';
    $my_post['post_author'] = 1;
    $my_post['post_category'] = array(1);
    $my_post['post_type'] = 'page';
    $my_post['comment_status'] = 'closed';
    $my_post['ping_status'] = 'closed';
    $postId = wp_insert_post( $my_post );
    return $postId;
}

/* Purpose: Create an 'Forums by Website Toolbox' settings menu under settings tab into WordPress admin menu.
Parameter: None
Return: None */
function websitetoolbox_add_admin_menu() {
    $wtbMenuName = 'Forums by Website Toolbox';
    if(get_option('websitetoolbox_username')) {
        add_options_page( 'WebsiteToolbox', $wtbMenuName, 'manage_options', 'websitetoolboxUpdateOptions', 'websitetoolbox_admin_update_options');
        $wtbMenuName = '';
    }
    add_options_page( 'WebsiteToolbox', $wtbMenuName, 'manage_options', 'websitetoolboxoptions', 'websitetoolbox_admin_options');
}

/* Start plugin login option page */

/* Purpose: Create an Website Toolbox Login options page to set forum settings into WordPress admin section.
Parameter: None
Return: None */
function websitetoolbox_admin_init() {
    // To show plugin login description on Websitetoolbox login page on WordPress admin panel.
    add_settings_section(
        'websitetoolbox_settings_section',
        '<h2>Forums by Website Toolbox</h2>',
        'websitetoolbox_settings_desc',
        'websitetoolboxoptions'
    );
    // To show forum username option on forum login settings page on WordPress admin panel.
    add_settings_field(
        'websitetoolbox_username',
        'Website Toolbox Username',
        'websitetoolbox_username_option',
        'websitetoolboxoptions',
        'websitetoolbox_settings_section'
    );

    // To show forum password option on forum login settings page on WordPress admin panel.
    add_settings_field(
        'websitetoolbox_password',
        'Website Toolbox Password',
        'websitetoolbox_password_option',
        'websitetoolboxoptions',
        'websitetoolbox_settings_section'
    );
    // To show 'Log In' button on forum login settings page on WordPress admin panel.
    add_settings_field(
        'websitetoolbox_Login',
        '',
        'websitetoolbox_login_option',
        'websitetoolboxoptions',
        'websitetoolbox_settings_section'
    );
}

/* Purpose: Add description on forum login settings page into WordPress admin section.
Parameter: None
Return: None */
function websitetoolbox_settings_desc() {
    echo '<b>Please log in to your Website Toolbox account.</b>';
    echo '<p>Not a Website Toolbox Forum owner? <a href="https://www.websitetoolbox.com/wordpress" target="_blank">Create a Forum Now!</a></p>';
    echo '<p>Please <a href="https://www.websitetoolbox.com/contact?subject=WordPress+Plugin+Setup+Help" target="_blank">Contact Customer Support</a> if you need help getting set up.</p>';
}

/* Purpose: Add username option on Forum login settings page into WordPress Forum settings page.
Parameter: None
Return: None */
function websitetoolbox_username_option($args) {
    $websitetoolbox_username = isset($_POST['websitetoolbox_username']) ? $_POST['websitetoolbox_username'] : get_option('websitetoolbox_username');
    $html = '<input type="text" name="websitetoolbox_username" id="websitetoolbox_username" value="'.$websitetoolbox_username.'" size="30"/>';
    echo $html;
}

/* Purpose: Add password option on Forum login settings page into WordPress Forum settings page.
Parameter: None
Return: None */
function websitetoolbox_password_option($args) {
    $html = '<input type="password" name="websitetoolbox_password" id="websitetoolbox_password" value="" size="30"/>';
    echo $html;
}

/* Purpose: Add "Log In" option on Forum login settings page into WordPress Forum settings page.
Parameter: None
Return: None */
function websitetoolbox_login_option($args) {
    $html = submit_button('Log In');;
    echo $html;
}

/* Purpose: This function is used to show forum login settings page. Also show error message if any.
Param: none
Return: Nothing */
function wtbForumSettingsPage($message = "") {
    if($message == 'username' || $message == 'password') {
        echo "<div id='wtb-warning' class='error'><p>Please enter forum $message.</p></div>";
    } else if($message && $message != 'success') {
        echo "<div id='wtb-warning' class='error'><p>$message</p></div>";
    }
    ?>
    <!-- create a form in the wordpress admin panel -->
    <div class="wrap">
        <form name="form_lol" action="options-general.php?page=websitetoolboxoptions" method="POST" onsubmit="ValidateForm();">
            <?php do_settings_sections( 'websitetoolboxoptions' ); ?>
        </form>
    </div>
    <?php
}
/* End plugin login page. */

/* Purpose: Validate login and add/update data in the WordPress database once login is validated.
Param: none
Return: Nothing */
function websitetoolbox_admin_options() {
    if($_POST) {
        global $wpdb;
        // Check if username is blank then show error message.
        if($_POST['websitetoolbox_username'] == "") {
            wtbForumSettingsPage('username');
            exit;
        }
        // Check if password is blank then show error message.
        if($_POST['websitetoolbox_password'] == "") {
            wtbForumSettingsPage('password');
            exit;
        }
        // Validate the forum if submit the form after fill website toolbox username and password.
        if(isset($_POST['websitetoolbox_username']) && isset($_POST['websitetoolbox_password'])) {
            // Validate login information (Website Toolbox) provided by the user.
            $response_array = checkPluginLogin($_POST['websitetoolbox_username'], $_POST['websitetoolbox_password']);
            //Show error message if any error message return in the response other wise stire forum address and API key in a varible het in the JSON response.
            if(!is_wp_error( $response_array )) {
                $response = trim(wp_remote_retrieve_body($response_array));
                $response = json_decode($response);
                if($response->{'errorMessage'}) {
                    #show error message to the user.
                    $errorMessage = $response->{'errorMessage'};
                    $errorMessage = preg_replace('#^Error:#', '', $errorMessage);
                    wtbForumSettingsPage($errorMessage);
                    exit;
                } else {
                    $forum_address = $response->{'forumAddress'};
                    $forumApliKey  = $response->{'forumApiKey'};
                }
            }
            $firstSetup = 0;
            # remove the backslash at the end for consistency
            $forum_address = preg_replace('#/$#', '', $forum_address);
            // Check forum alrady integrated on the WordPress website on a page/post or cutom link.
            // If forum already integrated then used same page instead of creating a new page.
            $wtbExist = 1;
            $wtbForumpageid = forumExists($forum_address);
            // If forum didn't already integrated on the WordPress Website page/post or custom link then create anew page for the forum.
            if(!$wtbForumpageid) {
                $wtbExist = 0;
                $wtbForumpageid = create_websitetoolbox_page();
            }
            // get page/post data.
            $pageData = get_post($wtbForumpageid);
            // Preapre array to save data (forum pageid, username, api key and forum address) in the WordPress database for future use.
            $wtbOptions = array(
                'websitetoolbox_pageid' => $wtbForumpageid,
                'websitetoolbox_username' => $_POST['websitetoolbox_username'],
                'websitetoolbox_api' => $forumApliKey,
                'websitetoolbox_url' => $forum_address
            );
            // if page is embedded then add/update it as embedded otherwise as a normal link.
            $embedPageUrl;
            if($pageData->post_type == 'nav_menu_item') {
                $wtbOptions = array_merge($wtbOptions, array("websitetoolbox_redirect"=>''));
            } else {
                $embedPageUrl = $pageData->guid;
                $wtbOptions = array_merge($wtbOptions, array("websitetoolbox_redirect"=>1));
            }
            // Add/Update forum information (username, api key, forum address and embed or not) in the WordPress database.
            if(get_option("websitetoolbox_username")) {
                foreach ($wtbOptions as $key => $item) {
                    update_option($key, $item);
                }
            } else {
                foreach ($wtbOptions as $key => $item) {
                    add_option($key, $item);
                }
                $firstSetup = 1;
            }

            $websitetoolbox_url		 = get_option("websitetoolbox_url");
            #preapre array to add/update data in "PREFIX_postmeta" table in WordPress.
            $wtbMetaValue = array(
                '_links_to' => $websitetoolbox_url,
                '_links_to_target' => 'websitetoolbox',
                '_links_to_type' => 'custom_post_type',
                '_wtbredirect_active'=> '1',
                '_wp_page_template' => 'full-width-page.php'
            );
            // Added data in "PREFIX_postmeta" table if not exist, if exist then update it.
            if(sizeof(get_post_meta( $wtbForumpageid))) {
                foreach ($wtbMetaValue as $key => $item) {
                    update_post_meta( $wtbForumpageid, $key, $item );
                }
            } else {
                foreach ($wtbMetaValue as $key => $item) {
                    add_post_meta( $wtbForumpageid, $key, $item );
                }
            }
            // Appended http with the forum address if not alray added.
            if(preg_match('#^https?://#', get_option('websitetoolbox_url'))) {
                $wtb_url = $websitetoolbox_url;
            } else {
                $wtb_url = "http://".$websitetoolbox_url;
            }
            // Added/update forum page information in case of embedded and non-embedded.
            if($embedPageUrl) {
                $response_array = updateForumData($_POST['websitetoolbox_username'], $forumApliKey, $embedPageUrl);
                $wtb_embed_url = preg_replace('#^https?:#i', '', $wtb_url);
                #Set default title if not exist..
                if($pageData->post_title) {
                    $postTitle = $pageData->post_title;
                } else {
                    $postTitle = "Forum";
                }
                // Get page content if alrady added and then append embed code below it.
                if($pageData->post_content && strpos($pageData->post_content, $wtb_embed_url) !== false) {
                    $postContent = str_replace('<div id="wtEmbedCode"><script type="text/javascript" id="embedded_forum" src="'.$wtb_embed_url.'/js/mb/embed.js"></script><noscript><a href="'.$wtb_url.'">Forum</a></noscript></div>','',$pageData->post_content);
                } else {
                    $postContent = '<div id="wtEmbedCode"><script type="text/javascript" id="embedded_forum" src="'.$wtb_embed_url.'/js/mb/embed.js"></script><noscript><a href="'.$wtb_url.'">Forum</a></noscript></div>';
                }

                $postData = array(
                    'ID'           => $wtbForumpageid,
                    'post_title'   => $postTitle,
                    'post_content' => $postContent
                );
                wp_update_post($postData);
                update_post_meta( $wtbForumpageid, '_wtbredirect_active', '' );
            } else {
                #open forum in new tab independently.
                update_post_meta( $wtbForumpageid, '_wtbredirect_active', '1' );
            }
        }
        if($wtbExist) {
            $_SESSION['wtb_account_settings'] = 3;
        } else {
            $_SESSION['wtb_account_settings'] = 4;
        }

        wp_redirect("options-general.php?page=websitetoolboxUpdateOptions");
        exit;
    }
    wtbForumSettingsPage();
    ?>
    <script language="javascript">
        /* validate admin form information */
        function ValidateForm(){
            var websitetoolbox_username = document.getElementById('websitetoolbox_username').value;
            var websitetoolbox_password = document.getElementById('websitetoolbox_password').value;
            if(websitetoolbox_username=="") {
                alert("Please enter your forum username.");
                document.getElementById('websitetoolbox_username').focus();
                return false;
            }
            if(websitetoolbox_password=="") {
                alert("Please enter your forum password.");
                document.getElementById('websitetoolbox_password').focus();
                return false;
            }
        }
    </script>
    <?php
}

/* Purpose: to show settigns field into forum plugin settinga page.
Parameter: None
Return: None */
function websitetoolbox_admin_update() {
    // To show settings description on Websitetoolbox settings page on WordPress admin panel.
    add_settings_section(
        'websitetoolbox_settings_update_section',
        '<h2>Forums by Website Toolbox</h2>',
        'websitetoolbox_update_settings_desc',
        'websitetoolboxUpdateOptions'
    );
    // To show forum username as a text on forum settings page on WordPress admin panel.
    add_settings_field(
        'websitetoolboxUsername',
        'Website Toolbox Username',
        'websitetoolbox_update_username_option',
        'websitetoolboxUpdateOptions',
        'websitetoolbox_settings_update_section'
    );
    // To show forum embed option on forum settings page on WordPress admin panel.
    add_settings_field(
        'websitetoolbox_redirect',
        'Embed the forum:',
        'websitetoolbox_embed_option',
        'websitetoolboxUpdateOptions',
        'websitetoolbox_settings_update_section'
    );
    // To show "Update" button on forum settings page on WordPress admin panel.
    add_settings_field(
        'websitetoolbox_update',
        '',
        'websitetoolbox_update_option',
        'websitetoolboxUpdateOptions',
        'websitetoolbox_settings_update_section'
    );
}

/* Purpose: to show description on plugin settings page.
Parameter: None
Return: None */
function websitetoolbox_update_settings_desc() {
    echo '<p class="description">Please <a href="https://www.websitetoolbox.com/contact?subject=WordPress+Plugin+Setup+Help" target="_blank">Contact Customer Support</a> if you need help getting set up.</p>';
}

/* Purpose: to show forum username as text and "Change" link on the forum plugin settings page.
Parameter: None
Return: None */
function websitetoolbox_update_username_option($args) {
    $websitetoolbox_username = get_option('websitetoolbox_username');
    $html = $websitetoolbox_username.'&nbsp;&nbsp;<a href="options-general.php?page=websitetoolboxoptions">Change</a>';
    echo $html;
}

/* Purpose: to show embed option as a check-box on the forum plugin settings page.
Parameter: None
Return: None */
function websitetoolbox_embed_option($args) {
    // enable Embed option when user install the plugin.
    if(!get_option('websitetoolbox_username')) {
        $checked = 1;
    } else {
        $checked = get_option('websitetoolbox_redirect');
    }
    $html = '<input type="checkbox" name="websitetoolbox_redirect" id="websitetoolbox_redirect" value="1" ' . checked(1, $checked, false) . '/>';
    $html .= '<label for="websitetoolbox_redirect">Yes</label>';
    $html .= '<p class="description" style="padding-top: 7px;">Enable this option to have your forum load within an iframe on your website.</p>
    <p class="description">Disable this option to have your forum load in a full-sized window. You can use the Layout section in your Website Toolbox account to <a href="https://www.websitetoolbox.com/support/making-your-forum-layout-match-your-website-148" target="_blank">customize your forum layout to match your website</a> or <a href="https://www.websitetoolbox.com/contact?subject=Customize+Forum+Layout" target="_blank">contact Website Toolbox support to customize it for you</a>.</p>';
    echo $html;
}

/* Purpose: To show update button on the forum plugin settings page.
Parameter: None
Return: None */
function websitetoolbox_update_option($args) {
    $html = submit_button('Update');;
    echo $html;
}

/* Purpose: To show plugin settigns page as well as error and success message.
Parameter: None
Return: None */
function wtbForumUpdateSettingsPage($message = "") {
    $pid = get_option('websitetoolbox_pageid');
    if(isset($_SESSION['wtb_account_settings']) && $_SESSION['wtb_account_settings'] == 3) {
        unset($_SESSION['wtb_account_settings']);
        echo '<div id="setting-error-settings_updated" class="updated notice"><p>Congrats! Single Sign On between your website and forum has been enabled.</p></div>';
    } else if(isset($_SESSION['wtb_account_settings']) && $_SESSION['wtb_account_settings'] == 4) {
        unset($_SESSION['wtb_account_settings']);
        $wtbForumpageid = get_option('websitetoolbox_pageid');
        $wtbPageData = get_post($wtbForumpageid);
        $embedPageUrl = $wtbPageData->guid;
        echo '<div id="setting-error-settings_updated" class="updated notice"><p>Congrats! Your forum has been embedded into your website, a new <a href='.$embedPageUrl.' target="_blank">Forum</a> link has been added to your website navigation, and Single Sign On between your website and forum has been enabled.</p></div>';
    } else if($message) {
        echo '<div id="setting-error-settings_updated" class="updated notice"><p>Your settings have been updated.</p></div>';
    }
    ?>
    <!-- create a form in the wordpress admin panel -->
    <div class="wrap">
        <form name="form_lol" action="options-general.php?page=websitetoolboxUpdateOptions" method="POST" >
            <?php do_settings_sections( 'websitetoolboxUpdateOptions' ); ?>
        </form>
    </div>
    <?php
}

/* Purpose: Add/update data in WordPress as well as update data SSO URLS on the forum via HTTP request.
Parameter: None
Return: None */
function websitetoolbox_admin_update_options() {
    if($_POST) {
        global $wpdb;
        $embedPageUrl;
        // Preapre array to set forum username, API and embed option.
        $wtbOptions = array(
            'websitetoolbox_username' => get_option('websitetoolbox_username'),
            'websitetoolbox_api' => get_option('websitetoolbox_apikey')
        );
        $websitetoolbox_url		 = get_option("websitetoolbox_url");
        $wtbForumpageid = get_option('websitetoolbox_pageid');
        if(preg_match('#^https?://#', get_option('websitetoolbox_url'))) {
            $wtb_url = $websitetoolbox_url;
        } else {
            $wtb_url = "http://".$websitetoolbox_url;
        }
        $pageData = get_post($wtbForumpageid);
        // Add/update data if embeded option is enable.
        if(isset($_POST['websitetoolbox_redirect'])) {
            $postTitle = $pageData->post_title;
            // Create a new page for forum if forum is alrady integrated as a custom link on WordPress website.
            // User save settings after enable "Embed" option. So that didn't effect on custom link.
            if($pageData->post_type == 'nav_menu_item') {
                $wtbForumpageid = create_websitetoolbox_page();
                // Update page id in options table
                update_option('websitetoolbox_pageid', $wtbForumpageid);
                #check on post meta
                $wtbMetaValue = array(
                    '_links_to' => $websitetoolbox_url,
                    '_links_to_target' => 'websitetoolbox',
                    '_links_to_type' => 'custom_post_type',
                    '_wtbredirect_active'=> '1',
                    '_wp_page_template' => 'full-width-page.php'
                );
                if(sizeof(get_post_meta( $wtbForumpageid))) {
                    foreach ($wtbMetaValue as $key => $item) {
                        update_post_meta( $wtbForumpageid, $key, $item );
                    }
                } else {
                    foreach ($wtbMetaValue as $key => $item) {
                        add_post_meta( $wtbForumpageid, $key, $item );
                    }
                }
                $pageData = get_post($wtbForumpageid);
                $postTitle = 'Forum';
            }
            // Add/update embed code for the forum page on WordPress.
            $embedPageUrl = $pageData->guid;
            $wtb_embed_url = preg_replace('#^https?:#i', '', $wtb_url);
            $postContent = '<div id="wtEmbedCode"><script type="text/javascript" id="embedded_forum" src="'.$wtb_embed_url.'/js/mb/embed.js"></script><noscript><a href="'.$wtb_url.'">Forum</a></noscript></div>';

            $postData = array(
                'ID'           => $wtbForumpageid,
                'post_title'   => $postTitle,
                'post_content' => $postContent
            );
            $response_array = updateForumData(get_option('websitetoolbox_username'), get_option('websitetoolbox_apikey'), $embedPageUrl);
            update_option('websitetoolbox_redirect', 1);
            wp_update_post($postData);
            update_post_meta( $wtbForumpageid, '_wtbredirect_active', '' );
        } else {
            #Remove embed code and set it as a link if "embed" option is disabled.
            $response_array = updateForumData(get_option('websitetoolbox_username'), get_option('websitetoolbox_apikey'));
            update_option('websitetoolbox_redirect', '');
            update_post_meta( $wtbForumpageid, '_wtbredirect_active', '1' );
        }
        wtbForumUpdateSettingsPage('success');
        exit;
    }
    wtbForumUpdateSettingsPage();
}
/* End Upate option page */

/* Purpose: Execute a HTTP request to validate forum login provided by the user.
Parameter: forum username, forum password.
Return: JSON responce */
function checkPluginLogin($forumUsername, $forumPassword) {
    if(get_option('users_can_register')) {
        $websitetoolbox_login_url = wp_login_url();
        if(!wtbValidateUrl($websitetoolbox_login_url)) {
            $websitetoolbox_login_url = '';
        }
        // Get Logout URL and remove "_wpnonce" and it's value from the URL if exist.
        // "_wpnonce" paramete's value is a dynamic key diffrent for every logged-in user so we need to remove it befor save into SSO logout URL into our forum.
        $websitetoolbox_logout_url = html_entity_decode(esc_url(wp_logout_url()));
        $websitetoolbox_logout_url = remove_query_arg( '_wpnonce', $websitetoolbox_logout_url );
        if(!wtbValidateUrl($websitetoolbox_logout_url)) {
            $websitetoolbox_logout_url = '';
        }
        $websitetoolbox_register_url = wp_registration_url();
        if(!wtbValidateUrl($websitetoolbox_register_url)) {
            $websitetoolbox_register_url = '';
        }
    }
    $fields = array(
            'action' => 'checkPluginLogin',
            'type' =>'json',
            'username' => $forumUsername,
            'password' => $forumPassword,
            'login_page_url' => $websitetoolbox_login_url,
            'logout_page_url' => $websitetoolbox_logout_url,
            'registration_url' => $websitetoolbox_register_url
        );
    $response_array = wp_remote_post(WTBSETTINGSPAGEURL, array('method' => 'POST', 'body' => $fields));
    return $response_array;
}

/* Purpose: Execute a HTTP request to update SSO URLs (Registration, login logout and embed URL) on the forum
Parameter: forum username, forum API Key, embedded URL.
Return: JSON responce */
function updateForumData($forumUsername, $forumAPI, $embedUrl = "") {
    // If registration option is enable from WordPress site then sent login, logout, registration URL into HTTP request.
    if(get_option('users_can_register')) {
        $websitetoolbox_login_url = wp_login_url();

        if(!wtbValidateUrl($websitetoolbox_login_url)) {
            $websitetoolbox_login_url = '';
        }
        // Get Logout URL and remove "_wpnonce" and it's value from the URL if exist.
        // "_wpnonce" paramete's value is a dynamic key diffrent for every logged-in user so we need to remove it befor save into SSO logout URL into our forum.
        $websitetoolbox_logout_url = html_entity_decode(esc_url(wp_logout_url()));
        $websitetoolbox_logout_url = remove_query_arg( '_wpnonce', $websitetoolbox_logout_url );
        if(!wtbValidateUrl($websitetoolbox_logout_url)) {
            $websitetoolbox_logout_url = '';
        }
        $websitetoolbox_register_url = wp_registration_url();
        if(!wtbValidateUrl($websitetoolbox_register_url)) {
            $websitetoolbox_register_url = '';
        }
    }
    $fields = array(
            'action' => 'modifySSOURLs',
            'forumUsername' => $forumUsername,
            'forumApikey' => $forumAPI,
            'login_page_url' => $websitetoolbox_login_url,
            'logout_page_url' => $websitetoolbox_logout_url,
            'registration_url' => $websitetoolbox_register_url,
            'embed_page_url' => $embedUrl
        );
    $response_array = wp_remote_post(WTBSETTINGSPAGEURL, array('method' => 'POST', 'body' => $fields));
    return $response_array;
}

#delete user if username exist on the forum
function wp_delete_user_current( $id, $reassign = 'novalue' ) {
    global $wpdb;
    $id = (int) $id;
    // allow for transaction statement
    do_action('delete_user', $id);
    if ( 'novalue' === $reassign || null === $reassign ) {
        $post_ids = $wpdb->get_col( $wpdb->prepare("SELECT ID FROM $wpdb->posts WHERE post_author = %d", $id) );
        if ( $post_ids ) {
            foreach ( $post_ids as $post_id )
            wp_delete_post($post_id);
        }
        // Clean links
        $link_ids = $wpdb->get_col( $wpdb->prepare("SELECT link_id FROM $wpdb->links WHERE link_owner = %d", $id) );
        if ( $link_ids ) {
            foreach ( $link_ids as $link_id )
            wp_delete_link($link_id);
        }
    } else {
        $reassign = (int) $reassign;
        $wpdb->update( $wpdb->posts, array('post_author' => $reassign), array('post_author' => $id) );
        $wpdb->update( $wpdb->links, array('link_owner' => $reassign), array('link_owner' => $id) );
    }
    clean_user_cache($id);
    // FINALLY, delete user
    if ( !is_multisite() ) {
        $wpdb->query( $wpdb->prepare("DELETE FROM $wpdb->usermeta WHERE user_id = %d", $id) );
        $wpdb->query( $wpdb->prepare("DELETE FROM $wpdb->users WHERE ID = %d", $id) );
    } else {
        $level_key = $wpdb->get_blog_prefix() . 'capabilities'; // wpmu site admins don't have user_levels
        $wpdb->query("DELETE FROM $wpdb->usermeta WHERE user_id = $id AND meta_key = '{$level_key}'");
    }
    // allow for commit transaction
    do_action('deleted_user', $id);
    return true;
}

/* Purpose: Show warning message on the plugin settings page.
Parameter: None.
Return: None */
function wtb_warning() {
    if(isset($_SESSION['wtbPluginActivated']) && (!get_option("websitetoolbox_username") || !get_option("websitetoolbox_api") || !get_option("websitetoolbox_url"))) {
        echo "<div id='wtb-warning' class='error'>
              <p>Thanks for installing the Forums by Website Toolbox plugin! Please <a href='options-general.php?page=websitetoolboxoptions'>enable your forum</a></p>
              </div>";
        unset($_SESSION['wtbPluginActivated']);
    } else if(isset($_SESSION['wtb_account_settings'])) {
        if($_SESSION['wtb_account_settings'] == 1) {
            echo '<div id="wtb-warning" class="error"><p>Your Website Toolbox forum account is currently disabled. Please <a href="https://www.websitetoolbox.com/tool/members/login/'.get_option("websitetoolbox_username").'" target="_blank">login to your Website Toolbox account</a> for more information.</a></p></div>';
        } else if($_SESSION['wtb_account_settings'] == 2) {
            echo '<div id="wtb-warning" class="error"><p>The API Key integrated with the Website Toolbox forum plugin is invalid. Please <a href="options-general.php?page=websitetoolboxoptions">log in</a> again to update it</p></div>';
        }
    }
}


/* Purpose: If a user deleted from WordPress site then delete from Forum.
Parameter: None
Return: None */
function deleteForumUser($args) {
    global $wpdb;
    #get All the user id's deleted from wordpress site.
    $userids = implode(",", $_POST['users']);
    #Get username from users table on the basis of userids.
    $user_names = $wpdb->get_results( "
        SELECT user_login
        FROM $wpdb->users
        WHERE ID IN ($userids)" );
    $unames = array();
    foreach ( $user_names as $usernames ) {
        $unames[] = $usernames->user_login;
    }
    #create a comma(,) separated string to sent user delete request on the Forum.
    if ( $unames ) {
        $usernames = implode(",", $unames);
    }
    $forum_api		= get_option("websitetoolbox_api");
    $forum_url		= get_option("websitetoolbox_url");
    // create URL to to delete users from related Forum.
    $URL = $forum_url."/register";
    $fields = array(
            'apikey' => $forum_api,
            'massaction' => 'decline_mem',
            'usernames' => $usernames
        );
    // Send http or https request to get authentication token.
    $response_array = wp_remote_post($URL, array('method' => 'POST', 'body' => $fields));
    if(!is_wp_error( $response_array )) {
        $response = trim(wp_remote_retrieve_body($response_array));
        // Decode json string
        $response = json_decode($response);
        if($response->{'success'}) {
            return true;
        }
    }
}

/* Purpose: Sent HTTP request on the related forum validate API and show error message if not validate.
Parameter: None
Return: None */
function checkForumEnableOrInvalidAPI() {
    // Check logged-in user is admin
    $user_ID = get_current_user_id();
    $is_admin = is_super_admin($user_ID);
    if(get_option("websitetoolbox_username") && get_option("websitetoolbox_api") && get_option("websitetoolbox_url") && $is_admin == 1) {
        // Create an arry of parameters
        $fields = array(
                'action' => 'checkAPIKey',
                'type' => 'json',
                'forumUsername' => get_option("websitetoolbox_username"),
                'forumApikey' => get_option("websitetoolbox_api")
            );
        // Sent HTTP request to forum.
        $response_array = wp_remote_post(WTBSETTINGSPAGEURL, array('method' => 'POST', 'body' => $fields));
        // Print warning if get any API ket not match.
        if(!is_wp_error( $response_array )) {
            $response = trim(wp_remote_retrieve_body($response_array));
            $response = json_decode($response);
            // Get authentication token from JSON response.
            if($response->{'error'}) {
                if($response->{'error'} == 'Error: The forum is disabled.') {
                    $_SESSION['wtb_account_settings'] = 1;
                } else {
                    $_SESSION['wtb_account_settings'] = 2;
                }
            } else {
                $_SESSION['wtb_account_settings'] = 0;
            }
        }
    }
}

/* Purpose: set plugin setting slink in WordPress menu.
Parameter: None
Return: None */
function addPluginSettingsLink( $links ) {
    $settings_link = '<a href="options-general.php?page=websitetoolboxoptions">Settings</a>';
    array_unshift( $links, $settings_link );
    return $links;
}
add_filter( "plugin_action_links_websitetoolbox", 'addPluginSettingsLink' );

/* Purpose: Check that forum is alrady integrated post/page or custom link on the WordPress website.
Parameter: Forum address, type (embed or non-embed)
Return: postid */
function forumExists($forum_address) {
    global $wpdb;
    // Check if forum as already linked using custom manu.
    $filter_data = $wpdb->get_results("SELECT post_id FROM {$wpdb->prefix}postmeta WHERE meta_value = '$forum_address'", ARRAY_A);
    $postId = 0;
    foreach ($filter_data as $key => $value) {
        if($value['post_id']) {
            $postId = $value['post_id'];
        }
    }

    # Check forum is already embedded in a post or page then.
    if(!$postId) {
        $forum_address = preg_replace('#^https?:#i', '', $forum_address);
        $filter_data = $wpdb->get_results("SELECT ID FROM {$wpdb->prefix}posts WHERE post_content like '%$forum_address%' AND (post_type = 'page' OR post_type = 'post')", ARRAY_A);
    }
    foreach ($filter_data as $key => $value) {
        if($value['ID']) {
            $postId = $value['ID'];
        }
    }
    return $postId;
}


/* Purpose: this function is used to validate the URL
Parameter: URL
Return: true/false */
function wtbValidateUrl($url) {
    if (filter_var($url, FILTER_VALIDATE_URL)) {
        return true;
    } else {
        return false;
    }
}

?>
